module Config.Pages.Debate.Arguments.Inferences.ImmortalityReductio exposing (..)

import Config.Pages.Debate.Arguments.Types exposing (..)


argumentImmortalityReductio : Argument
argumentImmortalityReductio =
    { argumentTitle = "Appeal to Nature Immortality Reductio"
    , propositionTitle = "Senescence does not result in death."
    , propositionReductio = "People who appeal to nature in this fashion assert that death cannot result from natural biological processes. Usually this is asserted in order to avoid accepting that LDL is causative of atherosclerosis."
    , propositionSummary = "If one commits to this variation of the appeal to nature fallacy, it's unclear why they wouldn't be subsequently committed to affirm that humans are immortal, like Connor fucking MacLeod."
    , proofLink = "https://www.umsu.de/trees/#(~6x~6y(Hx~5~3Rxy)),(Hs)%7C=(~3Rsd)"
    , argumentCertainty = 10
    , argumentImage = "immortality"
    , definitionTable =
        [ { definiendum = "P(x)"
          , definiens = "humans undergo (x)"
          }
        , { definiendum = "Q(x,y)"
          , definiens = "(x) results in (y)"
          }
        , { definiendum = "x"
          , definiens = "normal physiological process"
          }
        , { definiendum = "y"
          , definiens = "negative health outcome"
          }
        , { definiendum = "s"
          , definiens = "senescence"
          }
        , { definiendum = "d"
          , definiens = "death"
          }
        ]
    , argumentFormalization =
        [ { premises =
                [ { premise = "If humans undergo a normal physiological process, then the normal physiological process does not result in a negative health outcome."
                  , notation = "∀x∀y(Px→¬Qxy)"
                  }
                , { premise = "Humans undergo senescence."
                  , notation = "Ps"
                  }
                ]
          , conclusion = "Therefore, senescence does not result in death."
          , conclusionNotation = "¬Qsd"
          }
        ]
    }
