module Config.Pages.Debate.Arguments.Inferences.UnhealthyRedMeat exposing (..)

import Config.Pages.Debate.Arguments.Types exposing (..)


argumentUnhealthyRedMeat : Argument
argumentUnhealthyRedMeat =
    { argumentTitle = "Argument for Unhealthy Red Meat"
    , propositionTitle = "Red meat and processed meat are overwhelmingly unhealthy."
    , propositionReductio = ""
    , propositionSummary = "Even when you account for factors that could plausibly influence the results, unprocessed red meat has been shown to consistently increase the risk of morbidity and mortality, strongly suggesting that they directly contribute to worse health outcomes, particularly with respect to colorectal cancer and heart disease."
    , proofLink = "https://www.umsu.de/trees/#(~6x(Px~4Qx)),(Qm)|=(Pm)"
    , argumentCertainty = 7
    , argumentImage = "redmeat"
    , definitionTable =
        [ { definiendum = "P(x)"
          , definiens = "(x) is overwhelmingly unhealthy"
          }
        , { definiendum = "Q(x)"
          , definiens = "(x) consistently associates with an increased risk of morbidity and mortality after adjustment or control over relevant confounders and covariates"
          }
        , { definiendum = "x"
          , definiens = "a food"
          }
        , { definiendum = "m"
          , definiens = "redmeat"
          }
        ]
    , argumentFormalization =
        [ { premises =
                [ { premise = "For all things, a food is overwhelmingly unhealthy if, and only if, the food consistently associates with an increased risk of morbidity and mortality after adjustment or control over relevant confounders and covariates."
                  , notation = "∀x(Px↔Qx)"
                  }
                , { premise = "Unprocessed red meat consistently associates with an increased risk of morbidity and mortality after adjustment or control over relevant confounders and covariates."
                  , notation = "Qm"
                  }
                ]
          , conclusion = "Therefore, unprocessed red meat is overwhelmingly unhealthy."
          , conclusionNotation = "Pm"
          }
        ]
    }
