module Config.Pages.Debate.Gibberish.Domains.Epistemology exposing (..)

import Config.Helpers.Converters exposing (formatName)
import Config.Pages.Debate.Gibberish.Types exposing (..)


epistemologyGibberish : Gibberish
epistemologyGibberish =
    let
        name =
            "Epistemology"
    in
    { gibberishTitle = name
    , gibberishImage = formatName name
    , gibberishLink = "https://en.wikipedia.org/wiki/Epistemology"
    , gibberishDescription = "Epistemology is a branch of philosophy that investigates the nature, origin, and limits of knowledge. It addresses fundamental questions about what knowledge is, how it is acquired, and the criteria for its validity. By exploring concepts such as belief, truth, and justification, epistemology seeks to understand how humans comprehend and interpret reality."
    , gibberishTerms =
        [ { term = "Abductive Arguments"
          , strength = 3
          , explanation = SpecificExplanation "In a formal sense, I take an argument to be logical construct whereby the outputs consistently follow from an input, or set of inputs, according to a formal system of internally consistent rules or laws. Traditionally, abductive arguments are taken to fall outside this scope, so on my interpretation, the term \"abductive argument\" is probably gibberish."
          }
        , { term = "Content Internalism"
          , strength = 5
          , explanation = NoClue
          }
        , { term = "Externalist Epistemology"
          , strength = 0
          , explanation = SpecificExplanation "I don't take anything other than logic to be justification-giving. As such, any position that claims that justification can arrive through non-inferential means, such as mechanisms operating outside the mind, just sounds like gibberish."
          }
        , { term = "Inductive Arguments"
          , strength = 3
          , explanation = SpecificExplanation "In a formal sense, I take an argument to be logical construct whereby the outputs consistently follow from an input, or set of inputs, according to a formal system of internally consistent rules or laws. Traditionally, inductive arguments are taken to fall outside this scope, so on my interpretation, the term \"inductive argument\" is probably gibberish."
          }
        , { term = "Non-entailing Explanations"
          , strength = 2
          , explanation = SpecificExplanation "I take an explanation to be a set of premises that lead to a conclusion, so the term just sounds like some sort of contradiction."
          }
        , { term = "Non-inferential Justification"
          , strength = 0
          , explanation = SpecificExplanation "I don't take anything other than logic to be justification-giving. As such, any position that claims that justification can arrive through non-inferential means just sounds like gibberish."
          }
        , { term = "Phenomenal Conservatism"
          , strength = 0
          , explanation = SpecificExplanation "I don't take anything other than logic to be justification-giving. As such, any position that claims that justification can arrive through non-inferential means, such as merely having a seeming, just sounds like gibberish."
          }
        , { term = "Synthetic A Priori"
          , strength = 0
          , explanation = SpecificExplanation "I take a priori arguments to be arguments based on principles or axioms and not based on experience, which would seem to place a priori outside the purview of syntheticity."
          }
        , { term = "Warrant"
          , strength = 0
          , explanation = SpecificExplanation "This seems to be taken to be the thing that is justification-providing on phenomenal conservatism. I'm not sure what that thing is, but if it's non-inferential, then it's just gibberish."
          }
        ]
    }
